Installation
============

.. code-block:: bash

    $ poetry install Stegano

You will be able to use Stegano in your Python programs
or as a command line tool.

If you want to retrieve the source code (with the unit tests):

.. code-block:: bash

    $ git clone https://github.com/cedricbonhomme/Stegano
